[![PyPI - Version](https://img.shields.io/pypi/v/pypura?style=for-the-badge)](https://pypi.org/project/pypura/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pypura?style=for-the-badge)
[![Buy Me A Coffee/Beer](https://img.shields.io/badge/Buy_Me_A_☕/🍺-F16061?style=for-the-badge&logo=ko-fi&logoColor=white&labelColor=grey)](https://ko-fi.com/natekspencer)

![Pepy Total Downlods](https://img.shields.io/pepy/dt/pypura?style=flat-square)
![PyPI - Downloads](https://img.shields.io/pypi/dm/pypura?style=flat-square)

<picture>
  <source media="(prefers-color-scheme: dark)" srcset="https://brands.home-assistant.io/pura/dark_logo.png">
  <img alt="Pura logo" src="https://brands.home-assistant.io/pura/logo.png">
</picture>

# pypura

Python package for interacting with Pura smart fragrance diffusers

---

## Support Me

I'm not employed by Pura, and provide this library purely for your own enjoyment and home automation needs.

If you don't already own a Pura diffuser, please consider using [my referal code (JG5JN31)](http://rwrd.io/ref_JG5JN31) to get $20 off your first order of $50+ (as well as a tip to me in appreciation)!

If you already own a Pura diffuser and still want to donate, consider buying me a coffee ☕ (or beer 🍺) instead by using the link below or [sponsor me on Github](https://github.com/sponsors/natekspencer):

<a href='https://ko-fi.com/natekspencer' target='_blank'><img height='35' style='border:0px;height:46px;' src='https://az743702.vo.msecnd.net/cdn/kofi3.png?v=0' border='0' alt='Buy Me a Coffee at ko-fi.com' />
